@@ -2,6 +2,8 @@
  *
  * Copyright (C) 2006-2007 Collabora Ltd. <http://www.collabora.co.uk/>
  *
+ * SPDX-License-Identifier: MIT
+ *
  * Permission is hereby granted, free of charge, to any person
  * obtaining a copy of this software and associated documentation
  * files (the "Software"), to deal in the Software without
@@ -33,6 +35,8 @@
 /* Array ============================================================ */
 
 PyDoc_STRVAR(Array_tp_doc,
+"dbus.Array([iterable][, signature][, variant_level])\n"
+"\n"
 "An array of similar items, implemented as a subtype of list.\n"
 "\n"
 "As currently implemented, an Array behaves just like a list, but\n"
@@ -40,11 +44,7 @@ PyDoc_STRVAR(Array_tp_doc,
 "conversion of its items to D-Bus types is only done when it's sent in\n"
 "a Message. This might change in future so validation is done earlier.\n"
 "\n"
-"Constructor::\n"
-"\n"
-"    dbus.Array([iterable][, signature][, variant_level])\n"
-"\n"
-"``variant_level`` must be non-negative; the default is 0.\n"
+":py:attr:`variant_level` must be non-negative; the default is 0.\n"
 "\n"
 "``signature`` is the D-Bus signature string for a single element of the\n"
 "array, or None. If not None it must represent a single complete type, the\n"
@@ -53,13 +53,6 @@ PyDoc_STRVAR(Array_tp_doc,
 "\n"
 "If None (the default), when the Array is sent over\n"
 "D-Bus, the item signature will be guessed from the first element.\n"
-"\n"
-":IVariables:\n"
-"  `variant_level` : int\n"
-"    Indicates how many nested Variant containers this object\n"
-"    is contained in: if a message's wire format has a variant containing a\n"
-"    variant containing an array, this is represented in Python by an\n"
-"    Array with variant_level==2.\n"
 );
 
 static struct PyMemberDef Array_tp_members[] = {
@@ -68,8 +61,11 @@ static struct PyMemberDef Array_tp_members[] = {
      "instance)"},
     {"variant_level", T_LONG, offsetof(DBusPyArray, variant_level),
      READONLY,
-     "The number of nested variants wrapping the real data. "
-     "0 if not in a variant."},
+    "Indicates how many nested Variant containers this object\n"
+    "is contained in: if a message's wire format has a variant containing a\n"
+    "variant containing an array, this is represented in Python by an\n"
+    "Array with variant_level==2.\n"
+    },
     {NULL},
 };
 
@@ -169,27 +165,16 @@ Array_tp_init (DBusPyArray *self, PyObject *args, PyObject *kwargs)
         const char *c_str;
         PyObject *signature_as_bytes;
 
-        if (
-#ifdef PY3
-            !PyUnicode_Check(signature)
-#else
-            !PyBytes_Check(signature)
-#endif
-            )
+        if (!PyUnicode_Check(signature))
         {
             PyErr_SetString(PyExc_TypeError, "str expected");
             Py_CLEAR(signature);
             return -1;
         }
-#ifdef PY3
         if (!(signature_as_bytes = PyUnicode_AsUTF8String(signature))) {
             Py_CLEAR(signature);
             return -1;
         }
-#else
-        signature_as_bytes = signature;
-        Py_INCREF(signature_as_bytes);
-#endif
 
         c_str = PyBytes_AS_STRING(signature_as_bytes);
 
@@ -265,6 +250,8 @@ PyTypeObject DBusPyArray_Type = {
 /* Dict ============================================================= */
 
 PyDoc_STRVAR(Dict_tp_doc,
+"dbus.Dictionary(mapping_or_iterable=(), signature=None, variant_level=0)\n"
+"\n"
 "An mapping whose keys are similar and whose values are similar,\n"
 "implemented as a subtype of dict.\n"
 "\n"
@@ -273,11 +260,7 @@ PyDoc_STRVAR(Dict_tp_doc,
 "conversion of its items to D-Bus types is only done when it's sent in\n"
 "a Message. This may change in future so validation is done earlier.\n"
 "\n"
-"Constructor::\n"
-"\n"
-"    Dictionary(mapping_or_iterable=(), signature=None, variant_level=0)\n"
-"\n"
-"``variant_level`` must be non-negative; the default is 0.\n"
+":py:attr:`variant_level` must be non-negative; the default is 0.\n"
 "\n"
 "``signature`` is either a string or None. If a string, it must consist\n"
 "of exactly two complete type signatures, representing the 'key' type\n"
@@ -288,13 +271,6 @@ PyDoc_STRVAR(Dict_tp_doc,
 "If it is None (the default), when the Dictionary is sent over\n"
 "D-Bus, the key and value signatures will be guessed from an arbitrary\n"
 "element of the Dictionary.\n"
-"\n"
-":IVariables:\n"
-"  `variant_level` : int\n"
-"    Indicates how many nested Variant containers this object\n"
-"    is contained in: if a message's wire format has a variant containing a\n"
-"    variant containing an array of DICT_ENTRY, this is represented in\n"
-"    Python by a Dictionary with variant_level==2.\n"
 );
 
 static struct PyMemberDef Dict_tp_members[] = {
@@ -303,8 +279,11 @@ static struct PyMemberDef Dict_tp_members[] = {
      "that of each value in this Dictionary, as a Signature instance."},
     {"variant_level", T_LONG, offsetof(DBusPyDict, variant_level),
      READONLY,
-     "The number of nested variants wrapping the real data. "
-     "0 if not in a variant."},
+    "Indicates how many nested Variant containers this object\n"
+    "is contained in: if a message's wire format has a variant containing a\n"
+    "variant containing a dictionary, this is represented in Python by a\n"
+    "Dictionary with variant_level==2.\n"
+    },
     {NULL},
 };
 
@@ -404,20 +383,15 @@ Dict_tp_init(DBusPyDict *self, PyObject *args, PyObject *kwargs)
         const char *c_str;
         PyObject *signature_as_bytes;
 
-        if (!NATIVESTR_CHECK(signature)) {
+        if (!PyUnicode_Check(signature)) {
             PyErr_SetString(PyExc_TypeError, "str expected");
             Py_CLEAR(signature);
             return -1;
         }
-#ifdef PY3
         if (!(signature_as_bytes = PyUnicode_AsUTF8String(signature))) {
             Py_CLEAR(signature);
             return -1;
         }
-#else
-        signature_as_bytes = signature;
-        Py_INCREF(signature_as_bytes);
-#endif
 
         c_str = PyBytes_AS_STRING(signature_as_bytes);
         switch (c_str[0]) {
@@ -524,12 +498,10 @@ PyTypeObject DBusPyDict_Type = {
 static PyObject *struct_signatures;
 
 PyDoc_STRVAR(Struct_tp_doc,
+"dbus.Struct(iterable, signature=None, variant_level=0)\n"
+"\n"
 "An structure containing items of possibly distinct types.\n"
 "\n"
-"Constructor::\n"
-"\n"
-"    dbus.Struct(iterable, signature=None, variant_level=0) -> Struct\n"
-"\n"
 "D-Bus structs may not be empty, so the iterable argument is required and\n"
 "may not be an empty iterable.\n"
 "\n"
@@ -540,10 +512,10 @@ PyDoc_STRVAR(Struct_tp_doc,
 "If the signature is None (default) it will be guessed\n"
 "from the types of the items during construction.\n"
 "\n"
-"``variant_level`` must be non-negative; the default is 0.\n"
+":py:attr:`variant_level` must be non-negative; the default is 0.\n"
+"\n"
+".. py:attribute:: variant_level\n"
 "\n"
-":IVariables:\n"
-"  `variant_level` : int\n"
 "    Indicates how many nested Variant containers this object\n"
 "    is contained in: if a message's wire format has a variant containing a\n"
 "    variant containing a struct, this is represented in Python by a\n"
@@ -699,31 +671,8 @@ Struct_tp_getattro(PyObject *obj, PyObject *name)
 {
     PyObject *key, *value;
 
-#ifdef PY3
     if (PyUnicode_CompareWithASCIIString(name, "signature"))
         return dbus_py_variant_level_getattro(obj, name);
-#else
-    if (PyBytes_Check(name)) {
-        Py_INCREF(name);
-    }
-    else if (PyUnicode_Check(name)) {
-        name = PyUnicode_AsEncodedString(name, NULL, NULL);
-        if (!name) {
-            return NULL;
-        }
-    }
-    else {
-        PyErr_SetString(PyExc_TypeError, "attribute name must be string");
-        return NULL;
-    }
-
-    if (strcmp(PyBytes_AS_STRING(name), "signature")) {
-        value = dbus_py_variant_level_getattro(obj, name);
-        Py_CLEAR(name);
-        return value;
-    }
-    Py_CLEAR(name);
-#endif  /* PY3 */
 
     key = PyLong_FromVoidPtr(obj);
 
@@ -789,15 +738,12 @@ dbus_py_init_container_types(void)
 
     DBusPyArray_Type.tp_base = &PyList_Type;
     if (PyType_Ready(&DBusPyArray_Type) < 0) return 0;
-    DBusPyArray_Type.tp_print = NULL;
 
     DBusPyDict_Type.tp_base = &PyDict_Type;
     if (PyType_Ready(&DBusPyDict_Type) < 0) return 0;
-    DBusPyDict_Type.tp_print = NULL;
 
     DBusPyStruct_Type.tp_base = &PyTuple_Type;
     if (PyType_Ready(&DBusPyStruct_Type) < 0) return 0;
-    DBusPyStruct_Type.tp_print = NULL;
 
     return 1;
 }
